# Module <code>cdf_asset_source_model</code>

This module contains an Asset source model that illustrates how to create a customer-extended Asset that
is correctly tied to the global Asset source model. Follow this pattern to ensure that you can
easily upgrade to new versions of the Asset source model.
